@@ -27,9 +27,9 @@ readonly OLM_NAMESPACE="openshift-marketplace"
 
 # if you want to setup the nightly serving/eventing, set `release-next` OR
 # set release branch name for example: release-v0.19.1
-readonly SERVING_BRANCH="release-v0.19.0"
+readonly SERVING_BRANCH="release-next"
 # Pin the version due to issue in current nightly version
-readonly EVENTING_BRANCH="release-v0.19.2"
+readonly EVENTING_BRANCH="release-next"
 
 # Determine if we're running locally or in CI.
 if [ -n "$OPENSHIFT_BUILD_NAMESPACE" ]; then
@@ -37,11 +37,11 @@ if [ -n "$OPENSHIFT_BUILD_NAMESPACE" ]; then
 elif [ -n "$DOCKER_REPO_OVERRIDE" ]; then
   readonly TEST_IMAGE_TEMPLATE="${DOCKER_REPO_OVERRIDE}/{{.Name}}"
 elif [ -n "$BRANCH" ]; then
-  readonly TEST_IMAGE_TEMPLATE="registry.svc.ci.openshift.org/openshift/${BRANCH}:knative-client-test-{{.Name}}"
+  readonly TEST_IMAGE_TEMPLATE="registry.ci.openshift.org/openshift/${BRANCH}:knative-client-test-{{.Name}}"
 elif [ -n "$TEMPLATE" ]; then
   readonly TEST_IMAGE_TEMPLATE="$TEMPLATE"
 else
-  readonly TEST_IMAGE_TEMPLATE="registry.svc.ci.openshift.org/openshift/knative-nightly:knative-client-test-{{.Name}}"
+  readonly TEST_IMAGE_TEMPLATE="registry.ci.openshift.org/openshift/knative-nightly:knative-client-test-{{.Name}}"
 fi
 
 env
@@ -161,7 +161,7 @@ install_knative_serving_branch() {
   pushd /tmp/knative-serving
 
   source "openshift/e2e-common.sh"
-  IMAGE_FORMAT='registry.svc.ci.openshift.org/openshift/knative-nightly:${component}' install_knative || failed=1
+  IMAGE_FORMAT='registry.ci.openshift.org/openshift/knative-nightly:${component}' install_knative || failed=1
   popd
   return $failed
 }
@@ -203,12 +203,8 @@ install_serverless_operator_branch() {
   unset OPENSHIFT_BUILD_NAMESPACE
   unset OPENSHIFT_CI
 
-  # Replace deprecated registry.svc.ci with registry.ci until release branch is fixed
-  sed -i 's|registry.svc.ci.openshift.org/openshift/openshift-serverless-v1.13.0|registry.ci.openshift.org/openshift/openshift-serverless-v1.13.0|g' olm-catalog/serverless-operator/manifests/serverless-operator.clusterserviceversion.yaml
-  cat olm-catalog/serverless-operator/manifests/serverless-operator.clusterserviceversion.yaml
-
   # Install all components Serving,Eventing,Strimzi and Kafka
-  SCALE_UP=6 make install-all || failed=1
+  make install-all || failed=1
   subheader "Successfully installed serverless operator."
 
   header "Applying Strimzi Topic CR"
