@@ -17,21 +17,21 @@
 pkg_tar() {
   local dir
   case "$1" in
-    x86_64)
-		  dir=linux
+    amd64|arm64|ppc64le|s390x)
+		  dir=linux-$1
     	mkdir "${OUTDIR}/${dir}"
-    	mv kn-linux-amd64 ${OUTDIR}/${dir}/kn
+      mv kn-linux-$1 ${OUTDIR}/${dir}/kn
+      chmod +x ${OUTDIR}/${dir}/kn
       ;;
     macos)
-		  dir=macos
+		  dir=macos-amd64
     	mkdir "${OUTDIR}/${dir}"
     	mv kn-darwin-amd64 ${OUTDIR}/${dir}/kn
+      chmod +x ${OUTDIR}/${dir}/kn
       ;;
-      #uncomment following when we support building mentioned archs
-      #aarch64|ppc64le|s390x) dir=linux-${1};;
   esac
   cp LICENSE ${OUTDIR}/${dir}
-  tar -zcf kn-${dir}-amd64.tar.gz -C ${OUTDIR}/${dir} .
+  tar -zcf kn-${dir}.tar.gz -C ${OUTDIR}/${dir} .
 }
 
 pkg_zip_for_windows() {
@@ -44,6 +44,9 @@ pkg_zip_for_windows() {
 OUTDIR=$(mktemp -dt knbinary.XXXXXXXXXX)
 trap "rm -rf '${OUTDIR}'" EXIT INT TERM
 
-pkg_tar x86_64
+pkg_tar amd64
+pkg_tar arm64
+pkg_tar ppc64le
+pkg_tar s390x
 pkg_tar macos
 pkg_zip_for_windows
