@@ -18,7 +18,7 @@ import (
 	"testing"
 
 	"github.com/spf13/pflag"
-	"gotest.tools/assert"
+	"gotest.tools/v3/assert"
 	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/runtime/schema"
 )
@@ -39,12 +39,6 @@ type channelRefFlagsTestCase struct {
 
 func TestChannelTypesFlags(t *testing.T) {
 	cases := []*channelTypeFlagsTestCase{
-		{
-			"inbuilt alias 'imcv1beta1' case",
-			"imcv1beta1",
-			&schema.GroupVersionKind{Group: "messaging.knative.dev", Kind: "InMemoryChannel", Version: "v1beta1"},
-			"",
-		},
 		{
 			"inbuilt alias 'imc' case",
 			"imc",
@@ -95,12 +89,6 @@ func TestChannelTypesFlags(t *testing.T) {
 
 func TestChannelRefFlags(t *testing.T) {
 	cases := []*channelRefFlagsTestCase{
-		{
-			"inbuilt alias imcv1beta1 case",
-			"imcv1beta1:i1",
-			&corev1.ObjectReference{APIVersion: "messaging.knative.dev/v1beta1", Kind: "InMemoryChannel", Name: "i1"},
-			"",
-		},
 		{
 			"inbuilt alias 'imc' case",
 			"imc:i2",
@@ -116,7 +104,7 @@ func TestChannelRefFlags(t *testing.T) {
 		{
 			"default channel type prefix case",
 			"c1",
-			&corev1.ObjectReference{APIVersion: "messaging.knative.dev/v1beta1", Kind: "Channel", Name: "c1"},
+			&corev1.ObjectReference{APIVersion: "messaging.knative.dev/v1", Kind: "Channel", Name: "c1"},
 			"",
 		},
 		{
